import { CustomersIncludeEnum, CustomerIdFormField, Authentication } from '..';
/**
 * Parameters to get customer.
 */
export interface GetCustomersParameters {
    /**
     * Indicates whether to include customer sub-resources.
     */
    include?: CustomersIncludeEnum;
}
/**
 * Customer form field.
 */
export interface CustomerFormField {
    /**
     * Form field ID.
     */
    fieldId: string;
    /**
     * Form field value.
     */
    fieldValue: string;
}
/**
 * Parameters to create customer.
 */
export interface CreateCustomerParameters {
    /**
     * The first name of the customer.
     */
    first_name: string;
    /**
     * The last name of the customer.
     */
    last_name: string;
    /**
     * The email of the customer. Must be unique.
     */
    email: string;
    /**
     * Customer password.
     */
    password: string;
    /**
     * It determines if the customer is signed up to receive product review or abandoned cart emails or recieve both emails.
     */
    accepts_product_review_abandoned_cart_emails: boolean;
    /**
     * Array of channels the customer can access.
     */
    channel_ids?: number[];
    /**
     * Customer custom fields.
     */
    custom_fields: Array<CustomerFormField>;
    /**
     * Authentication information.
     */
    authentication?: Authentication;
    /**
     * Customer company.
     */
    company?: string;
    /**
     * Customer phone number.
     */
    phone?: string;
}
/**
 * Parameters to authenticate customer.
 */
export interface AuthCustomerParams {
    /**
     * Customer email address.
     */
    email: string;
    /**
     * Customer password.
     */
    password: string;
    /**
     * ChannelId to check the customer credentials against.
     * If this field is empty BigCommerce will use channel 1
     */
    channel_id?: number;
}
/**
 * Parameters to validate credentials.
 * Type alias for `AuthCustomerParams`.
 */
export declare type ValidateCredentialsParameter = AuthCustomerParams;
/**
 * Parameters to login customer.
 * Type alias for `AuthCustomerParams`.
 */
export declare type LoginCustomerParameters = AuthCustomerParams;
/**
 * Parameters to update customer form fields.
 */
export interface UpdateCustomerFormFieldsParameters {
    /**
     * Form field with customer ID.
     */
    data: CustomerIdFormField[];
}
/**
 * Parameters to update customer.
 */
export interface UpdateCustomerParameters {
    /**
     * Validation object that holds customer credentials. The profile will update only if the credentials are valid
     */
    validation: ValidateCredentialsParameter;
    /**
     * The first name of the customer.
     */
    first_name?: string;
    /**
     * The last name of the customer.
     */
    last_name?: string;
    /**
     * The email of the customer. Must be unique.
     */
    email?: string;
    /**
     * The company of the customer.
     */
    company?: string;
    /**
     * The phone number of the customer.
     */
    phone?: string;
    /**
     * Authentication information.
     */
    authentication?: Authentication;
    /**
     * It determines if the customer is signed up to receive product review or abandoned cart emails or recieve both emails.
     */
    accepts_product_review_abandoned_cart_emails?: boolean;
    /**
     * Arrays of channels the customer can access.
     */
    channel_ids?: number[];
}
//# sourceMappingURL=parameters.d.ts.map